!
! Daily update of leaf area index etc.
!
! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/Attic/stomate_netcdf.F90,v 1.2 2002/09/24 21:12:17 ssipsl Exp $
!
MODULE stomate_netcdf

  ! modules used:
 
  USE reqdprec

  IMPLICIT NONE

  INCLUDE "netcdf.inc"

  PRIVATE
  PUBLIC :: nf_put_att_stnd, &
            nf_get_att_stnd, &
            nf_def_var_stnd, &
            nf_put_var_stnd, &
            nf_get_var_stnd, &
            nf_put_vara_stnd, &
            nf_get_vara_stnd

  INTERFACE nf_put_var_stnd
    MODULE PROCEDURE nf_put_var_stnd_1d, nf_put_var_stnd_2d, nf_put_var_stnd_3d, nf_put_var_stnd_4d
  END INTERFACE

  INTERFACE nf_get_var_stnd
    MODULE PROCEDURE nf_get_var_stnd_1d, nf_get_var_stnd_2d, nf_get_var_stnd_3d, nf_get_var_stnd_4d
  END INTERFACE

  INTERFACE nf_put_vara_stnd
    MODULE PROCEDURE nf_put_vara_stnd_2d, nf_put_vara_stnd_3d
  END INTERFACE

  INTERFACE nf_get_vara_stnd
    MODULE PROCEDURE nf_get_vara_stnd_2d, nf_get_vara_stnd_3d
  END INTERFACE

CONTAINS

FUNCTION NF_PUT_ATT_STND( forcing_id, vid, nom, x_put ) RESULT(ier)

  INTEGER, INTENT(in)                   :: forcing_id
  INTEGER, INTENT(in)                   :: vid
  CHARACTER(LEN=*), INTENT(in)          :: nom

  REAL(stnd), INTENT(in)                :: x_put

  INTEGER                               :: ier

#ifdef NC_DOUBLE
  ier = NF_PUT_ATT_DOUBLE( forcing_id, vid, TRIM(nom), NF_DOUBLE, 1, x_put )
#else
  ier = NF_PUT_ATT_REAL( forcing_id, vid, TRIM(nom), NF_FLOAT, 1, x_put )
#endif

END FUNCTION NF_PUT_ATT_STND

FUNCTION NF_GET_ATT_STND( forcing_id, vid, nom, x_get ) RESULT(ier)
 
  INTEGER, INTENT(in)                   :: forcing_id
  INTEGER, INTENT(in)                   :: vid
  CHARACTER(LEN=*), INTENT(in)          :: nom

  REAL(stnd), INTENT(out)               :: x_get
 
  INTEGER                               :: ier
 
#ifdef NC_DOUBLE
  ier = NF_GET_ATT_DOUBLE( forcing_id, vid, TRIM(nom), x_get )
#else
  ier = NF_get_ATT_REAL( forcing_id, vid, TRIM(nom), x_get )
#endif
 
END FUNCTION NF_GET_ATT_STND

FUNCTION NF_DEF_VAR_STND( forcing_id, nom, ndim, idim, vid ) RESULT(ier)

  INTEGER, INTENT(in)                   :: forcing_id
  CHARACTER(LEN=*), INTENT(in)          :: nom
  INTEGER, INTENT(in)                   :: ndim
  INTEGER, DIMENSION(ndim), INTENT(in)  :: idim

  INTEGER, INTENT(out)                   :: vid

  INTEGER                               :: ier

#ifdef NC_DOUBLE
  ier = NF_DEF_VAR( forcing_id, TRIM(nom), NF_DOUBLE, ndim, idim, vid )
#else
  ier = NF_DEF_VAR( forcing_id, TRIM(nom), NF_REAL, ndim, idim, vid )
#endif

END FUNCTION NF_DEF_VAR_STND

FUNCTION NF_PUT_VAR_STND_1D( forcing_id, nom, x_put ) RESULT(ier)

  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:), INTENT(in)    :: x_put

  INTEGER                                 :: vid
  INTEGER                                 :: ier

  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )

#ifdef NC_DOUBLE
  ier = NF_PUT_VAR_DOUBLE( forcing_id, vid, x_put )
#else
  ier = NF_PUT_VAR_REAL( forcing_id, vid, x_put )
#endif

END FUNCTION NF_PUT_VAR_STND_1D

FUNCTION NF_PUT_VAR_STND_2D( forcing_id, nom, x_put ) RESULT(ier)
 
  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:,:), INTENT(in)  :: x_put
 
  INTEGER                                 :: vid
  INTEGER                                 :: ier
 
  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )
 
#ifdef NC_DOUBLE
  ier = NF_PUT_VAR_DOUBLE( forcing_id, vid, x_put )
#else
  ier = NF_PUT_VAR_REAL( forcing_id, vid, x_put )
#endif
 
END FUNCTION NF_PUT_VAR_STND_2D

FUNCTION NF_PUT_VAR_STND_3D( forcing_id, nom, x_put ) RESULT(ier)

  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:,:,:), INTENT(in)  :: x_put

  INTEGER                                 :: vid
  INTEGER                                 :: ier

  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )

#ifdef NC_DOUBLE
  ier = NF_PUT_VAR_DOUBLE( forcing_id, vid, x_put )
#else
  ier = NF_PUT_VAR_REAL( forcing_id, vid, x_put )
#endif

END FUNCTION NF_PUT_VAR_STND_3D

FUNCTION NF_PUT_VAR_STND_4D( forcing_id, nom, x_put ) RESULT(ier)

  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:,:,:,:), INTENT(in)  :: x_put

  INTEGER                                 :: vid
  INTEGER                                 :: ier

  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )

#ifdef NC_DOUBLE
  ier = NF_PUT_VAR_DOUBLE( forcing_id, vid, x_put )
#else
  ier = NF_PUT_VAR_REAL( forcing_id, vid, x_put )
#endif

END FUNCTION NF_PUT_VAR_STND_4D

FUNCTION NF_GET_VAR_STND_1D( forcing_id, nom, x_get ) RESULT(ier)

  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:), INTENT(out)   :: x_get

  INTEGER                                 :: vid
  INTEGER                                 :: ier

  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )

#ifdef NC_DOUBLE
  ier = NF_GET_VAR_DOUBLE( forcing_id, vid, x_get )
#else
  ier = NF_GET_VAR_REAL( forcing_id, vid, x_get )
#endif

END FUNCTION NF_GET_VAR_STND_1D

FUNCTION NF_GET_VAR_STND_2D( forcing_id, nom, x_get ) RESULT(ier)
 
  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:,:), INTENT(out) :: x_get
 
  INTEGER                                 :: vid
  INTEGER                                 :: ier
 
  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )
 
#ifdef NC_DOUBLE
  ier = NF_GET_VAR_DOUBLE( forcing_id, vid, x_get )
#else
  ier = NF_GET_VAR_REAL( forcing_id, vid, x_get )
#endif
 
END FUNCTION NF_GET_VAR_STND_2D

FUNCTION NF_GET_VAR_STND_3D( forcing_id, nom, x_get ) RESULT(ier)

  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:,:,:), INTENT(out) :: x_get

  INTEGER                                 :: vid
  INTEGER                                 :: ier

  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )

#ifdef NC_DOUBLE
  ier = NF_GET_VAR_DOUBLE( forcing_id, vid, x_get )
#else
  ier = NF_GET_VAR_REAL( forcing_id, vid, x_get )
#endif

END FUNCTION NF_GET_VAR_STND_3D

FUNCTION NF_GET_VAR_STND_4D( forcing_id, nom, x_get ) RESULT(ier)

  INTEGER, INTENT(in)                     :: forcing_id
  CHARACTER(LEN=*), INTENT(in)            :: nom
  REAL(stnd), DIMENSION(:,:,:,:), INTENT(out) :: x_get

  INTEGER                                 :: vid
  INTEGER                                 :: ier

  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )

#ifdef NC_DOUBLE
  ier = NF_GET_VAR_DOUBLE( forcing_id, vid, x_get )
#else
  ier = NF_GET_VAR_REAL( forcing_id, vid, x_get )
#endif

END FUNCTION NF_GET_VAR_STND_4D

FUNCTION NF_PUT_VARA_STND_2D( forcing_id, nom, start, count, x_put ) RESULT(ier)

  INTEGER, INTENT(in)                       :: forcing_id
  CHARACTER(LEN=*), INTENT(in)              :: nom
  INTEGER, DIMENSION(:), INTENT(in)         :: start, count
  REAL(stnd), DIMENSION(:,:), INTENT(in)    :: x_put

  INTEGER                                   :: vid
  INTEGER                                   :: ier

  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )

#ifdef NC_DOUBLE
  ier = NF_PUT_VARA_DOUBLE( forcing_id, vid, start, count, x_put )
#else
  ier = NF_PUT_VARA_REAL( forcing_id, vid, start, count, x_put )
#endif

END FUNCTION NF_PUT_VARA_STND_2D

FUNCTION NF_PUT_VARA_STND_3D( forcing_id, nom, start, count, x_put ) RESULT(ier)
 
  INTEGER, INTENT(in)                       :: forcing_id
  CHARACTER(LEN=*), INTENT(in)              :: nom
  INTEGER, DIMENSION(:), INTENT(in)         :: start, count
  REAL(stnd), DIMENSION(:,:,:), INTENT(in)  :: x_put
 
  INTEGER                                   :: vid
  INTEGER                                   :: ier
 
  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )
 
#ifdef NC_DOUBLE
  ier = NF_PUT_VARA_DOUBLE( forcing_id, vid, start, count, x_put )
#else
  ier = NF_PUT_VARA_REAL( forcing_id, vid, start, count, x_put )
#endif
 
END FUNCTION NF_PUT_VARA_STND_3D

FUNCTION NF_GET_VARA_STND_2D( forcing_id, nom, start, count, x_get ) RESULT(ier)
 
  INTEGER, INTENT(in)                       :: forcing_id
  CHARACTER(LEN=*), INTENT(in)              :: nom
  INTEGER, DIMENSION(:), INTENT(in)         :: start, count

  REAL(stnd), DIMENSION(:,:), INTENT(out)   :: x_get
 
  INTEGER                                   :: vid
  INTEGER                                   :: ier
 
  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )
 
#ifdef NC_DOUBLE
  ier = NF_GET_VARA_DOUBLE( forcing_id, vid, start, count, x_get )
#else
  ier = NF_GET_VARA_REAL( forcing_id, vid, start, count, x_get )
#endif
 
END FUNCTION NF_GET_VARA_STND_2D

FUNCTION NF_GET_VARA_STND_3D( forcing_id, nom, start, count, x_get ) RESULT(ier)
 
  INTEGER, INTENT(in)                       :: forcing_id
  CHARACTER(LEN=*), INTENT(in)              :: nom
  INTEGER, DIMENSION(:), INTENT(in)         :: start, count
 
  REAL(stnd), DIMENSION(:,:,:), INTENT(out) :: x_get
 
  INTEGER                                   :: vid
  INTEGER                                   :: ier
 
  ier = NF_INQ_VARID( forcing_id, TRIM(nom), vid )
 
#ifdef NC_DOUBLE
  ier = NF_GET_VARA_DOUBLE( forcing_id, vid, start, count, x_get )
#else
  ier = NF_GET_VARA_REAL( forcing_id, vid, start, count, x_get )
#endif
 
END FUNCTION NF_GET_VARA_STND_3D

END MODULE stomate_netcdf
